<?php
defined('BASEPATH') OR exit('No direct script access allowed');
?>
      <div class="main my-0">
        <div class="row mt-3 mx-0">
          <div class="col-md-9">
            <h3>Manage Outlets Demands</h3>
          </div>
          <div class="col-md-3 text-right">
            &nbsp;
          </div>
        </div>
        
        <div class="container_fluid mt-2 px-3">
		<form name="frmsearch" method="get" action="warehouse/<?php echo $mgmtname;?>">
         <table class="webforms sttbl bg-light my-0 table-responsive-sm">
          <tr>
           <td class="pr-0" width="20%"><input type="text" name="search" size="20" value="<?php echo $this->input->get("search");?>" placeholder="search Demand no."></td>
		<td class="pr-0" width="20%">
		<select name="outletid" id="outletid" >
		  <option value="">All Outlet</option>
						<?php
						if(is_array($outletlist) && count(array_filter($outletlist))>0)
						{

							foreach($outletlist as $outletrow)
							{
								$sel_outlet="";
								if(decodeValue($this->input->get("outletid"))==$outletrow->fld_id)
								{
									$sel_outlet = 'selected="selected"';
								}				
									?>
											<option value="<?php echo encodeValue($outletrow->fld_id);?>" <?php echo $sel_outlet;?>><?php echo $outletrow->fld_name;?></option>
									<?php
								
							}
						}
						?> 
		  </select>
		  </td>
           <td class="pr-0" width="10%"><input type="text" name="fromdate" id="fromdate" value="<?php echo $fromdate;?>"   placeholder="From Date" class="datepicker" style="width:120px;"/></td>
           <td class="pr-0" width="10%"><input type="text" name="todate" id="todate"  value="<?php echo $todate;?>" placeholder="To Date" class="datepicker" style="width:120px;"/></td>
            <td>
           	<button class="btn btn-dark pt-0 pb-1 px-2">Go</button>
           </td>         
          </tr>
         </table>
       </form>
         <?php
			if($this->session->flashdata("message")!="" && $this->session->flashdata("alerttype")!="")
			{
         ?>
         <div class="text-center my-4">
			 <span class="alert <?php echo $this->session->flashdata("alerttype");?>"><?php echo $this->session->flashdata("message");?></span>
         </div>
         <?php
			}
         ?>
         
         <table class="table mt-2 table-responsive-sm">
		 <form name="frmlisting" id="frmlisting" action="<?php echo base_url()."warehouse/".$mgmtname;?>" method="post" onsubmit=" return checkboxvalidate();">
                <thead>
                	<tr>
                    	<th width="5%">SRNo.</th>                    	
                    	<th width="15%">Demand No.</th>
                    	<th width="30%">Outlet</th>
                    	<th width="10%">Date</th>
                    	<th width="10%">Posted On</th>
                        <th width="5%" class="text-center">Status</th>
                        <th width="10%" class="text-center">Action</th>
                    </tr>
                    </thead>
                    <tbody>
					<?php
					if(is_array($results) && count(array_filter($results))>0)
					{
						$rowindex = 0;
						foreach($results as $row)
						{
							$rowindex++;


					?>
                    <tr>
                    	<td class="text-center"><?php echo $rowindex;?>.</td>
                    	<td><?php echo $row->fld_refno;?></td>    
						<td><?php echo $row->outletname;?></td>
                    	<td><?php echo dfltdtFormat($row->fld_refdate);?></td>           
                        
                    	<td><?php echo dfltdtFormat($row->fld_datetime);?></td>
                        <td align="center">
							<span class="text-<?php echo arrOSColor()[$row->fld_status];?>"><strong><?php echo arrOrderStatus()[$row->fld_status];?></strong></span>
                        </td>
                        <td align="center">
							<a href="warehouse/<?php echo $mgmtname;?>/view/<?php echo encodeValue($row->fld_id);?>" class="fancybox fancybox.iframe" aria-label="View" title="View"><span class="fa fa-eye fa-lg"></span></a>
							
							<a href="warehouse/<?php echo $mgmtname;?>/print/<?php echo encodeValue($row->fld_id);?>" class="fancybox fancybox.iframe" aria-label="Print" title="Print"><span class="fa fa-print fa-lg"></span></a>
							<a href="warehouse/<?php echo $mgmtname;?>/export/<?php echo encodeValue($row->fld_id);?>?<?php echo $_SERVER['QUERY_STRING'];?>" class="btn btn-success" title="Export">Export</a>

						<?php if($row->fld_status!='close'){ ?>
							<a href="warehouse/<?php echo $mgmtname;?>/closedemand/<?php echo encodeValue($row->fld_id);?>?<?php echo $_SERVER['QUERY_STRING'];?>" class="btn btn-danger" title="Close Demand">Close Demand</a>
							
							
							<?php
							}
							?>
						</td>
                    </tr>
                    <?php
						}
							
					}
					else
					{
                    ?>
                    <tr><td colspan="9" style="text-align:center">Record not found!</td></tr>
                    <?php
					}
                    ?>
                    
                    
                    </tbody>
                </table>
                 
	         <div class="clearfix"></div>
          
        </div>
        <div id="paginate" class="row">
			<?php echo $this->ajax_pagination->create_links(); ?>
        </div>
            
        </div>

